[LON-CAPA-cvs] cvs: loncom /interface lonaboutme.pm
weissno
weissno@source.lon-capa.org
Thu, 19 Feb 2009 11:11:22 -0000
weissno Thu Feb 19 11:11:22 2009 EDT
Modified files:
/loncom/interface lonaboutme.pm
Log:
weiss: changed "personal homepage" to "personal information page"
weiss: backround = consistent wording
Index: loncom/interface/lonaboutme.pm
diff -u loncom/interface/lonaboutme.pm:1.96 loncom/interface/lonaboutme.pm:1.97
--- loncom/interface/lonaboutme.pm:1.96 Tue Feb 17 10:24:54 2009
+++ loncom/interface/lonaboutme.pm Thu Feb 19 11:11:22 2009
@@ -1,7 +1,7 @@
# The LearningOnline Network
-# Personal Homepage
+# Personal Information Page
#
-# $Id: lonaboutme.pm,v 1.96 2009/02/17 10:24:54 weissno Exp $
+# $Id: lonaboutme.pm,v 1.97 2009/02/19 11:11:22 weissno Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -120,7 +120,7 @@
if ($target eq 'tex') {
$r->print('\noindent{\large\textbf{'.&mt('No user home page available').'}}\\\\\\\\');
} else {
- $r->print(&Apache::loncommon::start_page("Personal Homepage"));
+ $r->print(&Apache::loncommon::start_page("Personal Information Page"));
$r->print('<h2>'.&mt('No user home page available') .'</h2>'.
&mt('This is a result of one of the following:').'<ul>'.
'<li>'.&mt('The administrator of this domain has disabled home page functionality for this specific user.').'</li>'.
@@ -136,7 +136,7 @@
# --------------------------------------------------------- The syllabus fields
my %syllabusfields=&Apache::lonlocal::texthash(
'aaa_contactinfo' => 'Contact Information',
- 'bbb_aboutme' => 'Personal Homepage',
+ 'bbb_aboutme' => 'Personal Information Page',
'ccc_webreferences' => 'Web References');
# ------------------------------------------------------------ Get Query String
@@ -205,9 +205,9 @@
if ($env{'form.popup'}) {
$args->{'no_nav_bar'} = 1;
}
- $args->{'bread_crumbs'} = [{href=>"/adm/fhwfdev/$cnum/aboutme",text=>"Personal Homepage"}];
+ $args->{'bread_crumbs'} = [{href=>"/adm/fhwfdev/$cnum/aboutme",text=>"Personal Information Ppage"}];
my $start_page =
- &Apache::loncommon::start_page("Personal Homepage",$rss_link,$args);
+ &Apache::loncommon::start_page("Personal Information Page",$rss_link,$args);
$r->print($start_page);
$r->print('<div class="LC_ContentBoxSpecial">');
$r->print('<h2 class="LC_hcell">'.&Apache::loncommon::plainname($cnum,$cdom).'</h2>');
@@ -288,7 +288,7 @@
&Apache::lonnet::allowuploaded('/adm/aboutme',
$syllabus{'uploaded.photourl'});
#This call is to resize all "Personal Info" images in the LonCapa System. When its done, you can remove this line.
&Apache::lonnet::resizeImage(&Apache::lonnet::filelocation('',$syllabus{'uploaded.photourl'}));
#---End Resize---
@@ -539,8 +539,8 @@
if (!($env{'user.name'} eq 'public' && $env{'user.domain'} eq 'public')) {
&Apache::lonhtmlcommon::add_breadcrumb
({href=>"/adm/$cdom/$cnum/aboutme".$query_string,
- text=>"Personal Homepage - $name",
- title=>"Go to personal homepage for $name"}, {href=>"/adm/$cdom/$cnum/aboutme/portfolio",
+ text=>"Personal Information Page - $name",
+ title=>"Go to personal information page for $name"}, {href=>"/adm/$cdom/$cnum/aboutme/portfolio",
text=>"Viewable files - $name",
title=>"Viewable portfolio files for $name"}
);
@@ -288,7 +288,7 @@
&Apache::lonnet::allowuploaded('/adm/aboutme',
$syllabus{'uploaded.photourl'});
- #This call is to resize all "Personal Info" images in the LonCapa System. When its done, you can remove this line.
+ #This call is to resize all "Personal Information" images in the LonCapa System. When its done, you can remove this line.
&Apache::lonnet::resizeImage(&Apache::lonnet::filelocation('',$syllabus{'uploaded.photourl'}));
#---End Resize---